//
(function($){

	var form_fields = {};

	function esc(v)
	{
		return v.replace(/</g, '&#60;')
				.replace(/>/g, '&#62;')
				.replace(/\[/g, '&#91;')
				.replace(/\]/g, '&#93;')
				.replace(/"/g, '&#34;');
	}

	function populate_datalists()
	{
		var form_editor = $('textarea[id="wpcf7-form"]');

		if(form_editor.length)
		{
			try
			{
				var	form_structure = form_editor.val(),
					types = ['text','email','tel','url','textarea','number','range','date','checkbox','radio','select'],
					result = Array.from(form_structure.matchAll(new RegExp('\\[\\s*([^\\]]+)\\]', 'g'))),
					components,
					type,
					name,
					datalist_fields = $('datalist[id="cf7-field-name"]'),
					datalist_recordsets = $('datalist[id="cf7-recordset-id"]');

				form_fields = {};
				datalist_fields.html('');
				datalist_recordsets.html('');

				for(var i in result)
				{
					components = result[i][1].replace(/\s+/g, ' ').split(/\s/);
					type = components[0].replace(/\*/g, '').toLowerCase();
					name = components[1].replace(/"/g, '');
					if(types.indexOf(type) != -1)
					{
						form_fields[name] = type;
						$('<option />').attr('value', name).appendTo(datalist_fields);
					}
					else if(type == 'cf7-recordset')
					{
						components = result[i][1].match(/\sid\s*=\s*['"]([^'"]+)['"]/);
						if(components)
							$('<option />').attr('value', components[1]).appendTo(datalist_recordsets);
					}
				}

			}
			catch(err)
			{
				if(typeof console != 'undefined') console.log(err);
			}
		}
	}

	function display_datasource_section(datasource)
	{
		$('[class*="cf7-datasource-"]:not(.cf7-datasource-link):not(.cf7-datasource-recordset)').hide();
		$('.cf7-datasource-'+datasource).show();
		if(datasource == 'database') display_database_attributes();
	}

	function display_database_attributes()
	{
		$('.cf7-datasource-dns,.cf7-datasource-components').hide();
		$('.cf7-datasource-'+$('[name="cf7-database-connection"]:checked').val()).show();
	}

	function generate_recordset_shortcode()
	{
		var shortcode = '[cf7-recordset',
			p = '.cf7-datasource-recordset',
			cf7_recordset_id = $.trim($('[id="tag-generator-panel-cf7-recordset-id"]', p).val()),
			cf7_datasource = $.trim($('[name="cf7-datasource"]', p).val()),
			cf7_debugging = $('[name="cf7-debugging"]:checked', p).length,

			// User
			cf7_user_attributes = $.trim($('[name="cf7-user-attributes"]', p).val()),
			cf7_user_logged = $('[name="cf7-user-logged"]:checked', p).length,
			cf7_user_condition = $.trim($('[name="cf7-user-condition"]', p).val()),

			// Post
			cf7_post_attributes = $.trim($('[name="cf7-post-attributes"]', p).val()),
			cf7_post_condition = $.trim($('[name="cf7-post-condition"]', p).val()),

			// Taxonomy
			cf7_taxonomy_name = $.trim($('[name="cf7-taxonomy-name"]', p).val()),
			cf7_taxonomy_attributes = $.trim($('[name="cf7-taxonomy-attributes"]', p).val()),
			cf7_taxonomy_condition = $.trim($('[name="cf7-taxonomy-condition"]', p).val()),

			// Database
			cf7_database_connection = $.trim($('[name="cf7-database-connection"]:checked', p).val()),
			cf7_database_dns = $.trim($('[name="cf7-database-dns"]', p).val()),
			cf7_database_engine = $.trim($('[name="cf7-database-engine"]', p).val()),
			cf7_database_hostname = $.trim($('[name="cf7-database-hostname"]', p).val()),
			cf7_database_database = $.trim($('[name="cf7-database-database"]', p).val()),
			cf7_database_username = $.trim($('[name="cf7-database-username"]', p).val()),
			cf7_database_password = $.trim($('[name="cf7-database-password"]', p).val()),
			cf7_database_query = $.trim($('[name="cf7-database-query"]', p).val()),

			// CSV
			cf7_csv_url = $.trim($('[name="cf7-csv-url"]', p).val()),
			cf7_csv_headline = $('[name="cf7-csv-headline"]:checked', p).length,
			cf7_csv_delimiter = $.trim($('[name="cf7-csv-delimiter"]', p).val()),

			// JSON
			cf7_json_url = $.trim($('[name="cf7-json-url"]', p).val());

		shortcode += ' id="'+esc((cf7_recordset_id != '') ? cf7_recordset_id : 'recordset'+(new Date()).valueOf())+'"';
		shortcode += ' type="'+cf7_datasource+'"';

		if(cf7_debugging) shortcode += ' debug="1"';

		switch(cf7_datasource)
		{
			case 'user':
				if(cf7_user_attributes != '') shortcode += ' attributes="'+esc(cf7_user_attributes)+'"';
				if(cf7_user_logged) shortcode += ' logged="1"';
				if(cf7_user_condition != '') shortcode += ' condition="'+esc(cf7_user_condition)+'"';
			break;

			case 'post':
				if(cf7_post_attributes != '') shortcode += ' attributes="'+esc(cf7_post_attributes)+'"';
				if(cf7_post_condition != '') shortcode += ' condition="'+esc(cf7_post_condition)+'"';
			break;

			case 'taxonomy':
				if(cf7_taxonomy_name != '') shortcode += ' taxonomy="'+esc(cf7_taxonomy_name)+'"';
				if(cf7_taxonomy_attributes != '') shortcode += ' attributes="'+esc(cf7_taxonomy_attributes)+'"';
				if(cf7_taxonomy_condition != '') shortcode += ' condition="'+esc(cf7_taxonomy_condition)+'"';
			break;

			case 'database':
				if(cf7_database_connection == 'dns')
				{
					if(cf7_database_dns != '') shortcode += ' dns="'+esc(cf7_database_dns)+'"';
				}
				else
				{
					if(cf7_database_engine != '') shortcode += ' engine="'+esc(cf7_database_engine)+'"';
					if(cf7_database_hostname != '') shortcode += ' hostname="'+esc(cf7_database_hostname)+'"';
					if(cf7_database_database != '') shortcode += ' database="'+esc(cf7_database_database)+'"';
				}
				if(cf7_database_username != '') shortcode += ' username="'+esc(cf7_database_username)+'"';
				if(cf7_database_password != '') shortcode += ' password="'+esc(cf7_database_password)+'"';
				if(cf7_database_query != '') shortcode += ' query="'+esc(cf7_database_query)+'"';
			break;

			case 'csv':
				if(cf7_csv_url != '') shortcode += ' url="'+esc(cf7_csv_url)+'"';
				if(cf7_csv_headline) shortcode += ' headline="1"';
				if(cf7_csv_delimiter != '') shortcode += ' delimiter="'+esc(cf7_csv_delimiter)+'"';
			break;

			case 'json':
				if(cf7_json_url != '') shortcode += ' url="'+esc(cf7_json_url)+'"';
			break;
		}
		shortcode += ']';
		$('[name="cf7-recordset"]').val(shortcode);
	}

	function generate_link_shortcode()
	{
		var shortcode = '[cf7-link-field',
			p = '.cf7-datasource-link',
			cf7_recordset_id = $.trim($('[name="cf7-recordset-id"]', p).val()),
			cf7_field_name = $.trim($('[name="cf7-field-name"]', p).val()),
			cf7_attribute_value = $.trim($('[name="cf7-attribute-value"]', p).val()),
			cf7_attribute_text = $.trim($('[name="cf7-attribute-text"]', p).val()),
			cf7_condition = $.trim($('[name="cf7-condition"]', p).val());

		shortcode += ' recordset="'+esc(cf7_recordset_id)+'"';
		shortcode += ' field="'+esc(cf7_field_name)+'"';
		shortcode += ' value="'+esc(cf7_attribute_value)+'"';

		if(cf7_attribute_text != '') shortcode += ' text="'+esc(cf7_attribute_text)+'"';
		if(cf7_condition != '') shortcode += ' condition="'+esc(cf7_condition)+'"';

		shortcode += ']';
		$('[name="cf7-link-field"]').val(shortcode);
	}

	$(document).on('change', '[name="cf7-datasource"]',  function(){
		display_datasource_section($(this).val());
	});

	$(document).on('change', '[name="cf7-database-connection"]',  display_database_attributes);
	$(document).on('change keyup', '.cf7-datasource-recordset :input', generate_recordset_shortcode);
	$(document).on('change keyup', '.cf7-datasource-link :input', generate_link_shortcode);
	$(document).on('change keyup', '[name="cf7-field-name"]', function(){
		var cf7_field_name = $.trim(this.value),
			without_text_types = ['text','email','tel','url','textarea','number','range','date'],
			to_show_hide = $('[name="cf7-attribute-text"]').closest('tr');

		to_show_hide.show();
		if(cf7_field_name in form_fields && without_text_types.indexOf(form_fields[cf7_field_name]) != -1)
			to_show_hide.hide();
	});
	$(document).on('mousedown', '[href*="cf7-link-field"]', function(){
		populate_datalists();
	});
})(jQuery)