<?php
if(!class_exists('CF7_DATASOURCE_EDITOR'))
{
	class CF7_DATASOURCE_EDITOR
	{
		private $ds_manager;

		/********************** INSTANCE METHODS AND PROPERTIES **********************/
		public function __construct($ds_manager)
		{
			$this->ds_manager = $ds_manager;

			if(is_admin()) load_plugin_textdomain('cf7-datasource', false, dirname(__FILE__).'/../languages/');
			// Edit form
			add_action( 'wpcf7_admin_init' , array($this, 'tags_generator'), 999);

			// Informative notice
			add_action('admin_notices', array($this, 'help_notice'));
		} // End __construct

		private function admin_resources()
		{
			wp_enqueue_style('cf7_datasource_admin_style', plugins_url('/admin.css', __FILE__), array(), CF7_DATASOURCE::$version);
			wp_enqueue_script('cf7_datasource_admin_script', plugins_url('/admin.js', __FILE__), array('jquery'), CF7_DATASOURCE::$version);
		} // End js

		public function help_notice()
		{
			global $pagenow;
			$screen = get_current_screen();
			if($pagenow == 'admin.php' && $screen && $screen->parent_base == 'wpcf7')
			{
				echo '
					<div class="notice notice-info is-dismissible">'.
						__('<p>The <b>recordset</b> and <b>recordset field link</b> controls allow filling the form fields with data store in external data sources (user information, post data, taxonomies, database, CSV file, JSON). Learn their use with <b><a href="https://cf7-datasource.dwbooster.com/examples" target="_blank">Practical Examples</a></b>.', 'cf7-datasource').'</p>
					</div>
				';
			}
		} // End help_notice

		public function tags_generator()
		{
			if(!class_exists('WPCF7_TagGenerator')) return;
			$tag_generator = WPCF7_TagGenerator::get_instance();

			$tag_generator->add(
				'cf7-recordset',
				__( 'recordset', 'cf7-datasource' ),
				array($this,'tag_generator_recordset')
			);

			$tag_generator->add(
				'cf7-link-field',
				__( 'recordset field link', 'cf7-datasource' ),
				array($this,'tag_generator_link')
			);
		} // End tags_generator

		public function tag_generator_recordset($contact_form , $args = '')
		{
			$this->admin_resources();
			$args = wp_parse_args( $args, array() );
			$type = $args['id'];
		?>
			<div class="control-box cf7-datasource-recordset">
				<fieldset>
					<legend><?php _e('Generate a form-tag for a Recordset Field to read data from data-sources, like users data, posts information, taxonomies and databases<b><i>(CSV files, and JSON files are supported by the Professional version of the plugin)</i></b>', 'cf7-datasource');
					?>
					&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<a href="https://wordpress.org/support/plugin/cf7-data-source/" target="_blank" style="font-weight:bold;">
					<?php _e('Do you have a question?', 'cf7-datasource'); ?>
					</a>
					</legend>
					<?php
					if(current_user_can('manage_options')):
					?>
					<div style="padding:10px;font-size:1em;border:2px solid red; color:red;margin:5px 0;">
						<div>
							<?php
							_e('Upgrade to the <a href="https://cf7-datasource.dwbooster.com/download" target="_blank"><b>Professional version of the plugin</b></a> to get access to advanced data sources. <a href="https://cf7-datasource.dwbooster.com/download" target="_blank"><b>CLICK HERE</b></a>.', 'cf7-datasource');
							?>&nbsp;
							<?php
							_e('To try the premium data sources, visit the links: <a href="https://demos.dwbooster.com/cf7-datasource/wp-login.php" target="_blank">WordPress area</a>, and <a href="https://demos.dwbooster.com/cf7-datasource/" target="_blank">public website</a>', 'cf7-datasource');
							?>
						</div>
					</div>
					<?php
					endif;
					?>
					<table class="form-table">
						<tbody>
							<tr>
								<th scope="row"><?php echo esc_html( __('Id', 'cf7-datasource' ) ); ?></th>
								<td>
									<input aria-label="<?php esc_attr_e('Field id', 'cf7-datasource'); ?>" type="text" name="name" id="<?php print esc_attr($args['content'].'-id'); ?>" />
								</td>
							</tr>
							<tr>
								<th scope="row"><?php echo esc_html( __( 'Data source', 'cf7-datasource' ) ); ?></th>
								<td>
									<select name="cf7-datasource" aria-label="<?php esc_attr_e('Data source', 'cf7-datasource'); ?>">
										<?php
											print $this->ds_manager->admin_ds_options();
										?>
									</select>
								</td>
							</tr>
							<?php
								print $this->ds_manager->admin_ds_settings();
							?>
							<!-- Common -->
							<tr class="cf7-datasource">
								<th scope="row"><?php echo esc_html( __( 'Debugging ', 'cf7-datasource' ) ); ?></th>
								<td>
									<input aria-label="<?php esc_attr_e('Debugging', 'cf7-datasource'); ?>" type="checkbox" name="cf7-debugging" />
									<i><?php
										_e('If the checkbox is ticked the plugin registers the errors in the error_logs file', 'cf7-datasource');

										$error_logs_path = ini_get('error_log');
										if(
											!empty($error_logs_path) &&
											current_user_can('manage_options')
										) print '<br />'.$error_logs_path;
									?></i>
								</td>
							</tr>
						</tbody>
					</table>
				</fieldset>
			</div>

			<div class="insert-box" style="display:flex;overflow:hidden;">
				<input type="text" name="<?php echo $type; ?>" class="tag code" readonly="readonly" onfocus="this.select()" />

				<div class="submitbox">
					<input type="button" class="button button-primary insert-tag" value="<?php echo esc_attr( __( 'Insert Tag', 'contact-form-7' ) ); ?>" />
				</div>

				<br class="clear" />

			</div>
			<script>
				jQuery(function($){
					$('[name="cf7-datasource"]').change();
				});
			</script>
		<?php
		} // End tag_generator_recordset

		public function tag_generator_link($contact_form , $args = '')
		{
			$this->admin_resources();
			$args = wp_parse_args( $args, array() );
			$type = $args['id'];
		?>
			<div class="control-box cf7-datasource-link">
				<fieldset>
					<legend><?php _e('Generate a form-tag to link a Recordset field with another field in the form to populate it with data read from a data source, like the users data, posts information, taxonomies, databases, CSV files, and JSON files', 'cf7-datasource');
					?>
					&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;<a href="https://wordpress.org/support/plugin/cf7-data-source/" target="_blank" style="font-weight:bold;">
					<?php _e('Do you have a question?', 'cf7-datasource'); ?>
					</a>
					</legend>

					<table class="form-table">
						<tbody>
							<tr>
								<th scope="row"><?php echo esc_html( __('Id of recordset field', 'cf7-datasource' ) ); ?></th>
								<td>
									<input list="cf7-recordset-id" aria-label="<?php esc_attr_e('Id of recordset field', 'cf7-datasource'); ?>" type="text" name="cf7-recordset-id" placeholder="cf7-recordset-#" />
									<datalist id="cf7-recordset-id">
									</datalist>
									<br><i><?php _e('Enter the id of a recordset field in the form', 'cf7-datasource'); ?></i>
								</td>
							</tr>
							<tr>
								<th scope="row"><?php echo esc_html( __( 'Field name', 'cf7-datasource' ) ); ?></th>
								<td>
									<input list="cf7-field-name" aria-label="<?php esc_attr_e('Field name', 'cf7-datasource'); ?>" type="text" name="cf7-field-name" />
									<datalist id="cf7-field-name">
									</datalist>
									<br><i><?php _e('Enter the name of the field to populate', 'cf7-datasource'); ?></i>
								</td>
							</tr>
							<tr>
								<th scope="row"><?php echo esc_html( __( 'Attribute for value', 'cf7-datasource' ) ); ?></th>
								<td>
									<input aria-label="<?php esc_attr_e('Attribute for value', 'cf7-datasource'); ?>" type="text" name="cf7-attribute-value" />
									<br><i><?php _e('Ex. post_title for post title, or user_email for the email of the user', 'cf7-datasource'); ?></i>
								</td>
							</tr>
							<tr>
								<th scope="row"><?php echo esc_html( __( 'Attribute for text', 'cf7-datasource' ) ); ?></th>
								<td>
									<input aria-label="<?php esc_attr_e('Attribute for text', 'cf7-datasource'); ?>" type="text" name="cf7-attribute-text" />
									<br><i><?php _e('Use it with drop-down menu fields, checkbox and radio buttons. Ex. post_title', 'cf7-datasource'); ?></i>
								</td>
							</tr>
							<tr>
								<th scope="row"><?php echo esc_html( __( 'Condition for filtering', 'cf7-datasource' ) ); ?></th>
								<td>
									<input aria-label="<?php esc_attr_e('Condition for filtering', 'cf7-datasource'); ?>" type="text" name="cf7-condition" />
									<br><i><?php _e('Condition for filtering the record to use to populate the field from the recordset field. Ex. record[\'user_email\']==\'{field.user-email}\'', 'cf7-datasource'); ?></i>
								</td>
							</tr>
							<tr>
								<th scope="row"></th>
								<td style="text-align:right;">
									<a href="https://cf7-datasource.dwbooster.com/documentation#link-control" target="_blank" style="font-weight:bold;display:inline-block;padding:5px;border:2px solid #2271b1; color:#2271b1;text-decoration:none;"><?php _e('Data surce HELP', 'cf7-datasource');?></a>
								</td>
							</tr>
						</tbody>
					</table>
				</fieldset>
			</div>

			<div class="insert-box" style="display:flex;overflow:hidden;">
				<input type="text" name="<?php echo $type; ?>" class="tag code" readonly="readonly" onfocus="this.select()" />

				<div class="submitbox">
					<input type="button" class="button button-primary insert-tag" value="<?php echo esc_attr( __( 'Insert Tag', 'contact-form-7' ) ); ?>" />
				</div>

				<br class="clear" />

			</div>
		<?php
		} // End tag_generator_link
	} // End class CF7_DATASOURCE_EDITOR
}